kumoai.utils
============

Datasets
--------

Utilities listed here can be helpful for loading sample datasets to the Kumo
platform.

.. currentmodule:: kumoai.utils

.. autosummary::
   :nosignatures:
   :toctree: ../generated

   from_relbench


Visualization
-------------

Utilities listed here can be helpful for visualizing job outputs produced with
the Kumo SDK.

.. currentmodule:: kumoai.utils

.. autosummary::
   :nosignatures:
   :toctree: ../generated

   ForecastVisualizer
